/**
 * <p>Title: PCMCIA IO Sample Application</p>
 * <p>Description: PCMCIA IO Sample Application</p>
 * <p>Copyright: Copyright (c) 2005</p>
 * <p>Company: Mobile Satellite Services Corporation</p>
 * @author Poornima Sarvadevabhatla
 * @version 1.0
 */

import java.lang.RuntimeException;
import pcmciainterface.*;

public class MainClass {

  public static void main(String[] args) {
    Pcmcia pcmcia = new Pcmcia();
    try {
      pcmcia.getHandle();
      System.out.println("Got a handle");
    } catch (GetHandleException e) {
      e.printStackTrace();
    }


   int status = 0;

   byte[] valuesToBeWritten = new byte[]{//0x32};
         (byte) 0x40, //@
         (byte) 0x30,//0
         (byte) 0x30,//0
         (byte) 0x30,//0x31,//2
         (byte) 0x47,//G
         (byte) 0x4D,//M
         (byte) 0x49,//I
         (byte) 0x0D,//CR
         (byte) 0x0A};//LF,


    int address = 0;
    int noOfBytesToWrite = 9;
    status = pcmcia.writeIoFixAddr8bit(address, noOfBytesToWrite, valuesToBeWritten);
    if (status > 0) {
      System.out.println("Successfully wrote " + status + " bytes.");
      System.out.println("The following values were written:");
      for (int i = 0; i < status; i = i + 1) {
        System.out.println("Address " + (address) +
          ": Value written (dec): " + valuesToBeWritten[i] +
            "   (hex): " + zeroPadNumber(Integer.toHexString((int)valuesToBeWritten[i]).toUpperCase(),2));
      }
    }

    // Wait for the UC to answer
    try {
      Thread.sleep(1000);
    } catch (Exception e) {
    }

    byte[] readRegisterValue1 = new byte[50];
    status = pcmcia.readIoFixAddr8bit(0, 50, readRegisterValue1);
    System.out.println("Successfully read " + status + " bytes.");
    if (status > 0) {
      for (int i = 0; i < status; i = i + 1) {
        System.out.println("Read value #" + (i) +" (dec): " +
          ((int )readRegisterValue1[i]) + " (hex): " +
            (Integer.toHexString((int)readRegisterValue1[i])).toUpperCase());
      }
    }

    pcmcia.disposeHandle();
    System.out.println("Disposed a handle");
  }


/*******************************************************************************
*******************************************************************************/

  /** Zero-pads a <code>String[]</code>.
   *
   * @param StringToBePadded  the <code>String[]</code> to be zero-padded
   * @param totalNoOfDigits  Total number of characters the return value should
   * have. Must be greater or equal to the number of characters in the
   * <code>StringToBePadded</code> input parameter.
   * @return a zero-padded <code>String[]</code>
   */
  public static String zeroPadNumber(String StringToBePadded,
                                              int totalNoOfDigits){
    String returnString = StringToBePadded;
    if (StringToBePadded.length() > totalNoOfDigits) {
      return StringToBePadded.substring(0,totalNoOfDigits);
    }
    for (int i = 0; i < totalNoOfDigits-StringToBePadded.length() ; i = i + 1) {
      returnString = "0" + returnString;
    }
    return returnString;
  }

/*******************************************************************************
*******************************************************************************/
}